/// <reference path='fourslash.ts' />

////const /**/c = 0 ;

goTo.marker();
verify.quickInfoIs("const c: number");
